Introduction - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# WeeWX User's Guide

This is the complete guide to installing, configuring, and troubleshooting WeeWX.

## About WeeWX

WeeWX is software, written in Python, that interacts with a weather station to produce plots, reports, and HTML pages. It can optionally upload the reports to a remote Web server as well as publish to weather services such as WeatherUnderground, CWOP, or PWSweather.com.

Initial development began in the winter of 2008-2009, with the first release in 2009.

The source code is hosted on GitHub. Installation instructions and releases are available at weewx.com/downloads.